@@ -13,15 +13,15 @@ from ..core.constants import ShippingPartnerCodes_DICT
 from ..core.base_models import BaseModelTimeAndDeleted
 from ..core.model_function import get_object_or_None
 from ..core.common_utils import get_uuid4_hex
-from ..sparrow_orders.constants import AftersaleFinanceStatus
-from ..sparrow_orders.constants import RefundStatus
-from ..sparrow_orders.constants import AftersaleStatus
-from ..sparrow_orders.constants import AftersaleFinanceType
-from ..sparrow_orders.constants import AftersaleSource
-from ..sparrow_orders.constants import CancelSource
-from ..sparrow_orders.constants import AftersaleActions
+from ..sparrow_aftersale.constants import AftersaleFinanceStatus
+from ..sparrow_aftersale.constants import AftersaleRefundStatus
+from ..sparrow_aftersale.constants import AftersaleStatus
+from ..sparrow_aftersale.constants import AftersaleFinanceType
+from ..sparrow_aftersale.constants import AftersaleSource
+from ..sparrow_aftersale.constants import AftersaleCancelSource
+from ..sparrow_aftersale.constants import AftersaleActions
+from ..sparrow_aftersale.constants import AfterSaleType
 from ..sparrow_orders.constants import CouponSource
-from ..sparrow_orders.constants import AfterSaleType
 from ..sparrow_orders.constants import PayStepType
 from ..sparrow_orders.constants import PayMethod
 from ..sparrow_orders.models import generate_aftersale_number
@@ -77,9 +77,9 @@ class Afs(BaseModelTimeAndDeleted):
         (AftersaleFinanceStatus.REJECTED, "财务驳回")
     )
     REFUND_STATUS_CHOICES = (
-        (RefundStatus.INIT, "未退款"),
-        (RefundStatus.SUCCEEDED, "退款成功"),
-        (RefundStatus.FAILED, "退款失败")
+        (AftersaleRefundStatus.INIT, "未退款"),
+        (AftersaleRefundStatus.SUCCEEDED, "退款成功"),
+        (AftersaleRefundStatus.FAILED, "退款失败")
     )
     AFTERSALE_FINANCE_TYPE_CHOICES = (
         (AftersaleFinanceType.AUTO, "正常退单"),
@@ -90,9 +90,9 @@ class Afs(BaseModelTimeAndDeleted):
         (AftersaleSource.SERVICE_INITIATED, "客服发起"),
     )
     CANCEL_SOURCE_CHOICES = (
-        (CancelSource.GUEST_CANCEL, "客人取消"),
-        (CancelSource.SERVICE_CANCEL, "客服取消"),
-        (CancelSource.TIMEOUT_CANCEL, "超时自动取消"),
+        (AftersaleCancelSource.GUEST_CANCEL, "客人取消"),
+        (AftersaleCancelSource.SERVICE_CANCEL, "客服取消"),
+        (AftersaleCancelSource.TIMEOUT_CANCEL, "超时自动取消"),
     )
     AFTERSALE_TYPE_CHOICES = (
         (AfterSaleType.NORMAL, "正常退款"),
@@ -147,7 +147,7 @@ class Afs(BaseModelTimeAndDeleted):
         choices=REFUND_STATUS_CHOICES,
         blank=True,
         null=True,
-        default=RefundStatus.INIT)
+        default=AftersaleRefundStatus.INIT)
     # 财务要的退款时间，找财务确认是要发起微信退款的时间还是微信退款到账的时间
     # 应该是调起微信退款接口的时间
     refund_time = models.DateTimeField("发起退款的时间", blank=True, null=True, db_index=True)
