@@ -123,7 +123,9 @@ class Material(BaseModelTimeAndDeleted):
     spec = models.CharField("规格", max_length=20, null=True)
     # model varchar(20) 型号
     model = models.CharField("型号", max_length=20, null=True)
-    
+    # 排序规则
+    seq = models.IntegerField("排序", default=0)
+
     class Meta:
         app_label = APP_LABEL
         
